FriendLLy
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

``` sh
pip install friendlly
```

## How to use

``` python
import os
os.environ['ANTHROPIC_API_KEY'] = 'your-very-secret-anthropic-api-key'

# Or even better, use dotenv instead:
# (assuming you have an .env file with 'ANTHROPIC_API_KEY=your-very-secret-anthropic-api-key' in it)
import dotenv; dotenv.load_dotenv();
```

------------------------------------------------------------------------

``` python
%load_ext friendlly
```

``` python
%fr Hello there! My name is Alex.
# Hello Alex! It's nice to meet you. I'm an AI assistant created by Anthropic to be helpful,
# harmless, and honest. How can I help you today?

%fr
```
